# envedit
A tool to bulk manipulate environment variables
# WARNING - This is a work in progress and is not yet usable without a serious look in the source code
# TODO:
## envedit
- [x] Add support for filtering environment variables
- [x] Add support for replacing environment variables
## stackenv
- [ ] Add support for pushing: i.e create a version of an environment variable to which we can "pop" back.
- [ ] Add support for popping.


## Tests
- To run the unit tests, just run
```bash
./run_tests.sh
```
- To run the integration tests, run the following command
```bash
./run_integration_tests.sh
```
